==> hs-glade-0.12.0_1.tbz: lib/ghc-7.0.3/cabal/glade-0.12.0/register.sh <==
#!/bin/sh
echo 'name: glade
version: 0.12.0
id: glade-0.12.0-95635eaeaff68446912ce4696e9d97dd

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: This library allows to load externally stored user interfaces into
             programs. This allows alteration of the interface without recompilation
             of the program.
category: Graphics
author: Manuel M T Chakravarty
exposed: True
exposed-modules: Graphics.UI.Gtk.Glade
hidden-modules: Graphics.UI.Gtk.Glade.Types
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/glade-0.12.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/glade-0.12.0
              /usr/local/lib
hs-libraries: HSglade-0.12.0
extra-libraries: glade-2.0 gtk-x11-2.0 xml2 gdk-x11-2.0 atk-1.0
                 pangocairo-1.0 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite
                 Xdamage gdk_pixbuf-2.0 pangoft2-1.0 gio-2.0 Xfixes cairo X11
                 pango-1.0 m freetype fontconfig gobject-2.0 gmodule-2.0 gthread-2.0
                 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/libglade-2.0
              /usr/local/include/gtk-2.0 /usr/local/include/libxml2
              /usr/local/lib/gtk-2.0/include /usr/local/include/atk-1.0
              /usr/local/include/cairo /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/pango-1.0 /usr/local/include/gio-unix-2.0/
              /usr/local/include/glib-2.0 /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         cairo-0.12.0-0c72e956066deed849e92270e97178b5
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         glib-0.12.0-8144dd6b871a3f77547c0bef30f04b3e
         gtk-0.12.0-a4fda87069ff09531b8c7279ba868f94
         haskell98-1.1.0.1-b5235617d15eeebf246dacfc99755a36
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         pango-0.12.0-7fcdc5f504aa781bc2b80ff49775a65e
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/glade-0.12.0/html/glade.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/glade-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-glade-0.12.1.tbz: lib/ghc-7.0.4/cabal/glade-0.12.1/register.sh <==
#!/bin/sh
echo 'name: glade
version: 0.12.1
id: glade-0.12.1-852fbcbe9ba84360402519ea7a48feb4

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: This library allows to load externally stored user interfaces into
             programs. This allows alteration of the interface without recompilation
             of the program.
             .
             Note that this functionality is now provided in gtk directly
             (as of version 2.12 of the gtk+ C lib) by the
             Graphics.UI.Gtk.Builder module.
category: Graphics
author: Manuel M T Chakravarty, Duncan Coutts
exposed: True
exposed-modules: Graphics.UI.Gtk.Glade
hidden-modules: Graphics.UI.Gtk.Glade.Types
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/glade-0.12.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/glade-0.12.1
              /usr/local/lib
hs-libraries: HSglade-0.12.1
extra-libraries: glade-2.0 gtk-x11-2.0 xml2 gdk-x11-2.0 atk-1.0
                 pangocairo-1.0 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite
                 Xdamage gdk_pixbuf-2.0 pangoft2-1.0 gio-2.0 Xfixes cairo X11
                 pango-1.0 m freetype fontconfig gobject-2.0 gmodule-2.0 gthread-2.0
                 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/libglade-2.0
              /usr/local/include/gtk-2.0 /usr/local/include/libxml2
              /usr/local/lib/gtk-2.0/include /usr/local/include/atk-1.0
              /usr/local/include/cairo /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/pango-1.0 /usr/local/include/gio-unix-2.0/
              /usr/local/include/glib-2.0 /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         glib-0.12.2-14d626c7282f5f31da9b4a299a29106c
         gtk-0.12.2-eb6577e503c9105a0b596523a2dbc206
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/glade-0.12.1/html/glade.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/glade-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
